@@ -4,7 +4,7 @@ kerastuner <- NULL
 
 .onLoad <- function(libname, pkgname) {
   
-    kerastuner <<- reticulate::import("kerastuner", delay_load = list(
+    kerastuner <<- reticulate::import("keras_tuner", delay_load = list(
       priority = 10,
       environment = "r-tensorflow"
     ))
