@@ -14,15 +14,15 @@ test_succeeds("Can run hp-space", {
   mnist_train$x = tf$dtypes$cast(mnist_train$x, 'float32') / 255.
   mnist_test$x = tf$dtypes$cast(mnist_test$x, 'float32') / 255.
   
-  mnist_train$x = keras::k_reshape(mnist_train$x,shape = c(6e4,28,28))
-  mnist_test$x = keras::k_reshape(mnist_test$x,shape = c(1e4,28,28))
+  mnist_train$x = k_reshape(mnist_train$x,shape = c(6e4,28,28))
+  mnist_test$x = k_reshape(mnist_test$x,shape = c(1e4,28,28))
   
   
   hp = HyperParameters()
   hp$Choice('learning_rate',values =c(1e-1, 1e-3))
   hp$Int('num_layers', 2L, 20L)
   
-  testthat::expect_match(capture.output(hp),'keras_tuner.engine.hyperparameters.HyperParameters')
+  testthat::expect_match(capture.output(hp),'keras_tuner.engine.hyperparameters.hyperparameters.HyperParameters')
   
   
   mnist_model = function(hp) {
@@ -51,6 +51,10 @@ test_succeeds("Can run hp-space", {
     directory='my_dir4',
     project_name = 'mnist_')
   
+  tuner %>% fit_tuner(mnist_train$x, mnist_train$y,
+                       validation_split=0.2,
+                       epochs=1)  
+  
   testthat::expect_match(capture.output(tuner),'keras_tuner.tuners.randomsearch.RandomSearch')
 })
 
